***********************************
***MTURK ANALYSIS
***********************************
use RawData/mturk_SR_data.dta, clear

** DEMOGRAPHICS
egen pid=rmean(pid_dstr pid_rstr pid_lean)
label var pid "Party ID (-3=S. Dem; 3=S. Rep)"

gen age=2010-yob
label var age "Age (in years)"
gen age2=(age*age)/100
label var age2 "Age-squared/100"

label var educ "Education (1=No HS; 6=post-grad)"

foreach i in white black hispanic asian nativeam mixed other{
 replace r_`i'=0 if r_`i'==.
 replace r_`i'=1 if r_`i'!=0
 label var r_`i' "`i' = 1"
}
egen no_races=rowtotal(r_*)
replace r_other=1 if no_races>1 
foreach i in white black hispanic {
replace r_`i' = 0 if no_races>1
}
label var r_other "Other Race/Multiple/Refused = 1"
label var r_white "White = 1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"
drop r_asian r_nativeam r_mixed no_races
egen no_races=rowtotal(r_*)
replace r_other=1 if no_races==0

label var female "Female=1"

label var li_dontvote "Low Info: Don't Vote"
label var li_ballotorder "Low Info: First on Ballot"
label var li_party "Low Info: Preferred Party"
label var li_familiar "Low Info: Familiar Name"
label var li_priorsuccess "Low Info: Prior Career Success"
gen ranked_li=li_dontvote~=. & li_ballotorder~=. & li_party~=. & li_familiar~=. & li_priorsuccess~=.
egen ranked_miss=rmiss(li_dontvote  li_ballotorder li_party li_familiar li_priorsuccess)

** SAMPLE RESTRICTIOn
reg li_dontvote li_party li_priorsuccess li_familiar li_ballotorder r_black r_hispanic r_other age female educ pid , r
keep if e(sample)

*** SUMMARY STATISTICS
outsum r_white r_black r_hispanic r_other age female educ pid if ranked_li using "Tables/TableA1_summarystats", bracket append ctitle(Mechanical Turk Sample)

*********************************************************
*Calculate confidence intervals for rankings low info voting
*********************************************************
set seed 1523
foreach i in li_dontvote li_party li_priorsuccess li_familiar li_ballotorder {
 gen first_`i'=`i'==1
 reg first_`i' if ranked_li==1
 lincomest _cons
 est store first_`i'

 reg `i' if ranked_li==1
 lincomest _cons
 est store `i'
}

*** FIGURE 4
coefplot (first_li_dontvote, rename((1) = "Don't Vote" ) \  first_li_party, rename((1) = "Preferred Party" )  \ first_li_priorsuccess, rename((1) = "Prior Success" ) \ first_li_familiar, rename((1) = "Familiar Name" )\ first_li_ballotorder, rename((1) = "First on Ballot" )  yaxis(1) msymbol(S) connect(none) msize(small) mcolor(gs10) ciopts(lcolor(gs10) lwidth(thin) yaxis(1)) label(Proportion Ranking First)) (li_dontvote, rename((1) = "Don't Vote" ) \  li_party, rename((1) = "Preferred Party" )  \ li_priorsuccess, rename((1) = "Prior Success" ) \ li_familiar, rename((1) = "Familiar Name" )\ li_ballotorder, rename((1) = "First on Ballot" ) yaxis(2) msymbol(O) connect(none) msize(medium) mcolor(black) ciopts(lcolor(black) lwidth(thin) yaxis(2)) label(Mean Ranking)) , vertical level(95) coeflabels(,wrap(12)) title("Figure 4: Evaluation of Uninformed Voting Strategies",  size(med)) ytitle("Proportion Ranking First",  size(medsmall) axis(1)) ytitle("Mean Ranking",  size(medsmall) axis(2)) note("Note: Gray markers indicate the proportion of respondents who ranked each strategy as first (best);" "dark markers are mean rankings. Respondents ranked all options from 1 (best) to 5 (worst)." "Whiskers indicate 95% confidence intervals.",  size(small)) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white)) xscale(lw(none)) yscale(reverse axis(2)) ylabel(1 2 3 4 5, axis(2)) xlabel(, labsize(small)) legend(region(lcolor(white)) cols(2) size(small))
graph export "Figures/figure_4.tif", as(tif) width(4000) replace
//graph export "Figures\figure_4.pdf", as(pdf) replace

***Related to demographics?
foreach i in li_dontvote li_party li_priorsuccess li_familiar li_ballotorder {
reg `i' r_black r_hispanic r_other age female educ pid if ranked_li, r
test r_black r_hispanic r_other 
if "`i'"=="li_dontvote"{
outreg using "Tables/TableA5_turk_covariates", se bracket replace rdec(3) adec(3) addstat("Joint significance of race/ethnicity indicators (p-value)", r(p))
}
else{
outreg using "Tables/TableA5_turk_covariates", se bracket append rdec(3) adec(3) addstat("Joint significance of race/ethnicity indicators (p-value)", r(p))
}
}

foreach i in first_li_dontvote first_li_party first_li_priorsuccess first_li_familiar first_li_ballotorder {
reg `i' r_black r_hispanic r_other age female educ pid if ranked_li, r
test r_black r_hispanic r_other 
if "`i'"=="first_li_dontvote"{
outreg using "Tables/TableA6_turk_covariates_first", se bracket replace rdec(3) adec(3) addstat("Joint significance of race/ethnicity indicators (p-value)", r(p))
}
else{
outreg using "Tables/TableA6_turk_covariates_first", se bracket append rdec(3) adec(3) addstat("Joint significance of race/ethnicity indicators (p-value)", r(p))
}
}
